ElementsList

Trait ElementsList 

pub trait ElementsList {
    // Required methods
    fn get_element_ids(&self) -> Vec<ElementId>;
    fn get_parent_id(&self, id: ElementId) -> Option<ElementId>;
}
Lists known elements and parent relationships for a layout tree snapshot.

Required Methods

fn get_element_ids(&self) -> Vec<ElementId>

Returns all known element IDs.

fn get_parent_id(&self, id: ElementId) -> Option<ElementId>

Returns the parent ID for id, if any.

Returns None when the element is the root or unknown.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors