Keyboard key enums and keyboard/text provider traits.
Enums
- Keyboard
Key - Normalized keyboard key identifiers used by Cotis input providers.
Constants
- KEYBOARD_
LIST - Full key list for integrations that poll every key each frame.
Traits
- Simple
Keyboard Provider - Provides the current set of pressed keys for the active frame.
- Simple
Text Provider - Provides the characters typed during the current frame.