CotisRenderContext

Trait CotisRenderContext 

pub trait CotisRenderContext: CotisWindowContext + CotisFrameContext { }
Combined renderer context required by Cotis integrations.

This is a marker supertrait over CotisWindowContext and CotisFrameContext. Any type that implements both subtraits automatically implements this trait as well; renderers only need to implement window dimensions and delta time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors