Module keyboard

Module keyboard 

Keyboard key enums and keyboard/text provider traits.

Enums

KeyboardKey
Normalized keyboard key identifiers used by Cotis input providers.

Constants

KEYBOARD_LIST
Full key list for integrations that poll every key each frame.

Traits

SimpleKeyboardProvider
Provides the current set of pressed keys for the active frame.
SimpleTextProvider
Provides the characters typed during the current frame.